import { miniAppList } from "@/services/distributor/miniApp"
import { PageContainer, ProTable } from "@ant-design/pro-components"
import { Button, Modal, QRCode, Table } from "antd"
import { columns, childrenColumns } from "./tableConfig"
import { useAjax } from "@/Hook/useAjax"
import { corpListOfPage, corpPreAuth } from "@/services/distributor/corpManage"
import { useEffect, useRef, useState } from "react"
import { PlusOutlined } from "@ant-design/icons"

const Page: React.FC = () => {
    let getList = useAjax((params) => corpListOfPage(params), { type: 'table' })
    let [codeOpen, setCodeOpen] = useState<string>("")
    let [codeState, setCodeState] = useState<"active" | "loading" | "expired" | "scanned">("active")
    let CorpPreAuth = useAjax(() => corpPreAuth())
    let timeRef = useRef<any>()
    const auth = () => {
        CorpPreAuth.run().then(res => {
            if (res.data) {
                setCodeOpen(res.data)
                setCodeState("active")
                run()
            }
        })
    }
    const run = () => {
        if (timeRef.current) {
            clearInterval(timeRef.current)
        }
        timeRef.current = setInterval(() => {
            setCodeState("expired")
        }, 1000 * 60)
    }
    return <PageContainer>
        <ProTable<any, any>
            headerTitle={"企微列表"}
            rowKey={(r) => r.id}
            search={{
                labelWidth: 120,
            }}
            scroll={{ x: "auto" }}
            request={async (params) => {
                return await getList.run(params)
            }}
            columns={columns()}
            toolBarRender={() => [
                <Button type="primary" onClick={auth} ><PlusOutlined />新增企微</Button>,
            ]}
            expandable={{
                rowExpandable: (record) => record?.appCarrierList?.length > 0,
                expandRowByClick: true,
                expandedRowRender: (record) => {
                    return <Table
                        columns={childrenColumns}
                        dataSource={record.appCarrierList}
                        rowKey={(r) => r.id}
                        pagination={false}
                        size='small'
                        bordered
                    />
                },
            }}
        />
        <Modal
            footer={null}
            open={!!codeOpen}
            onCancel={() => {
                setCodeOpen(""); clearInterval(timeRef.current)
            }}
            maskClosable={false}
            width={350}
            title="企微管理员扫码授权">
            <QRCode size={300} type="svg" value={codeOpen} onRefresh={auth} status={codeState} />
        </Modal>
    </PageContainer>

}
export default Page